@@ -123,7 +123,7 @@ def r14(p, nlhc, residual, definiteRange, y, e, vv, asdf1, C,
             if any(o_exclude_ind):
                 tmp2[o_exclude_ind] = nan
                 if not isSNLE:
-                    g = min((g, min(o[o_exclude_ind])))
+                    g = PythonMin(g, min(o[o_exclude_ind]))
             tnlh_curr = tnlh_fixed_local - log2(tmp2)
 #            tnlh_curr[ind_inf] = 1e300
         else:
@@ -158,10 +158,10 @@ def r14(p, nlhc, residual, definiteRange, y, e, vv, asdf1, C,
         r40 = Min
         xRecord = xk.copy()# TODO: is copy required?
     
-    r41 = PythonMin((Min, r41))
+    r41 = PythonMin(Min, r41)
     
     fo = \
-    float(0 if isSNLE else PythonMin((r41, r40 - (fTol if maxSolutions == 1 else 0))))
+    float(0 if isSNLE else PythonMin(r41, r40 - (fTol if maxSolutions == 1 else 0)))
 
     if p.solver.dataHandling == 'raw':
         
@@ -190,7 +190,7 @@ def r14(p, nlhc, residual, definiteRange, y, e, vv, asdf1, C,
 #                    else:
 #                        p.Time += time() - tt
                     
-            tmp = asarray([node.key for node in an])
+            tmp = array([node.key for node in an])
             cond = tmp > fo
             r10 = where(cond)[0]
             g = PythonMin([an[i].key for i in r10]+[g])
@@ -256,10 +256,10 @@ def r14(p, nlhc, residual, definiteRange, y, e, vv, asdf1, C,
     
     #p.iterfcn(xk, Min)
     p.iterfcn(xRecord, r40)
-    if not isSNLE and isfinite(r40) and len(an):
+    if not isSNLE and isfinite(r41) and len(an):
         tmp = array([node.key for node in an])
-        cond_exclude = r40 - tmp <= \
-        p.rTol * where(abs(tmp) < abs(r40), abs(tmp), abs(r40))
+        cond_exclude = r41 - tmp <= \
+        p.rTol * where(abs(tmp) < abs(r41), abs(tmp), abs(r41))
         g = PythonMin([g] + [an[j].key for j in where(cond_exclude)[0]])
         cond_remain = logical_not(cond_exclude)
         ind = where(cond_remain)[0]
